/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.adsense.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for ReportingMetadataEntry.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the AdSense Management API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ReportingMetadataEntry extends GenericJson {

  /**
   * For metrics this is a list of dimension IDs which the metric is compatible with, for dimensions
   * it is a list of compatibility groups the dimension belongs to.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> compatibleDimensions;

  /**
   * The names of the metrics the dimension or metric this reporting metadata entry describes is
   * compatible with.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> compatibleMetrics;

  /**
   * Unique identifier of this reporting metadata entry, corresponding to the name of the
   * appropriate dimension or metric.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Kind of resource this is, in this case adsense#reportingMetadataEntry.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The names of the dimensions which the dimension or metric this reporting metadata entry
   * describes requires to also be present in order for the report to be valid. Omitting these will
   * not cause an error or warning, but may result in data which cannot be correctly interpreted.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> requiredDimensions;

  /**
   * The names of the metrics which the dimension or metric this reporting metadata entry describes
   * requires to also be present in order for the report to be valid. Omitting these will not cause
   * an error or warning, but may result in data which cannot be correctly interpreted.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> requiredMetrics;

  /**
   * The codes of the projects supported by the dimension or metric this reporting metadata entry
   * describes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> supportedProducts;

  /**
   * For metrics this is a list of dimension IDs which the metric is compatible with, for dimensions
   * it is a list of compatibility groups the dimension belongs to.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getCompatibleDimensions() {
    return compatibleDimensions;
  }

  /**
   * For metrics this is a list of dimension IDs which the metric is compatible with, for dimensions
   * it is a list of compatibility groups the dimension belongs to.
   * The value set may be {@code null}.
   */
  public ReportingMetadataEntry setCompatibleDimensions(java.util.List<String> compatibleDimensions) {
    this.compatibleDimensions = compatibleDimensions;
    return this;
  }

  /**
   * The names of the metrics the dimension or metric this reporting metadata entry describes is
   * compatible with.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getCompatibleMetrics() {
    return compatibleMetrics;
  }

  /**
   * The names of the metrics the dimension or metric this reporting metadata entry describes is
   * compatible with.
   * The value set may be {@code null}.
   */
  public ReportingMetadataEntry setCompatibleMetrics(java.util.List<String> compatibleMetrics) {
    this.compatibleMetrics = compatibleMetrics;
    return this;
  }

  /**
   * Unique identifier of this reporting metadata entry, corresponding to the name of the
   * appropriate dimension or metric.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Unique identifier of this reporting metadata entry, corresponding to the name of the
   * appropriate dimension or metric.
   * The value set may be {@code null}.
   */
  public ReportingMetadataEntry setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * Kind of resource this is, in this case adsense#reportingMetadataEntry.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Kind of resource this is, in this case adsense#reportingMetadataEntry.
   * The value set may be {@code null}.
   */
  public ReportingMetadataEntry setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The names of the dimensions which the dimension or metric this reporting metadata entry
   * describes requires to also be present in order for the report to be valid. Omitting these will
   * not cause an error or warning, but may result in data which cannot be correctly interpreted.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getRequiredDimensions() {
    return requiredDimensions;
  }

  /**
   * The names of the dimensions which the dimension or metric this reporting metadata entry
   * describes requires to also be present in order for the report to be valid. Omitting these will
   * not cause an error or warning, but may result in data which cannot be correctly interpreted.
   * The value set may be {@code null}.
   */
  public ReportingMetadataEntry setRequiredDimensions(java.util.List<String> requiredDimensions) {
    this.requiredDimensions = requiredDimensions;
    return this;
  }

  /**
   * The names of the metrics which the dimension or metric this reporting metadata entry describes
   * requires to also be present in order for the report to be valid. Omitting these will not cause
   * an error or warning, but may result in data which cannot be correctly interpreted.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getRequiredMetrics() {
    return requiredMetrics;
  }

  /**
   * The names of the metrics which the dimension or metric this reporting metadata entry describes
   * requires to also be present in order for the report to be valid. Omitting these will not cause
   * an error or warning, but may result in data which cannot be correctly interpreted.
   * The value set may be {@code null}.
   */
  public ReportingMetadataEntry setRequiredMetrics(java.util.List<String> requiredMetrics) {
    this.requiredMetrics = requiredMetrics;
    return this;
  }

  /**
   * The codes of the projects supported by the dimension or metric this reporting metadata entry
   * describes.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getSupportedProducts() {
    return supportedProducts;
  }

  /**
   * The codes of the projects supported by the dimension or metric this reporting metadata entry
   * describes.
   * The value set may be {@code null}.
   */
  public ReportingMetadataEntry setSupportedProducts(java.util.List<String> supportedProducts) {
    this.supportedProducts = supportedProducts;
    return this;
  }

}
